slepc-3.18.0 2022-10-01
Report Typos and Errors

# NEPSLPGetEPSLeft

Retrieve the linear eigensolver object (EPS) associated to the nonlinear eigenvalue solver, used to compute left eigenvectors in the two-sided variant of SLP.

### Synopsis

    #include "slepcnep.h"
    PetscErrorCode NEPSLPGetEPSLeft(NEP nep,EPS *eps)

Not Collective

### Input Parameter

| nep | - nonlinear eigenvalue solver

### Output Parameter

| eps | - the eigensolver object

### See Also

NEPSLPSetEPSLeft(), NEPSetTwoSided()

### Level

advanced

### Location

src/nep/impls/slp/slp.c
Index of all NEP routines
Table of Contents for all manual pages
Index of all manual pages